package com.ruoyi.ems.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import io.swagger.annotations.Api;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.log.annotation.Log;
import com.ruoyi.common.log.enums.BusinessType;
import com.ruoyi.common.security.annotation.RequiresPermissions;
import com.ruoyi.ems.domain.OpEnergyStrategy;
import com.ruoyi.ems.service.IOpEnergyStrategyService;
import com.ruoyi.common.core.web.controller.BaseController;
import com.ruoyi.common.core.web.domain.AjaxResult;
import com.ruoyi.common.core.utils.poi.ExcelUtil;
import com.ruoyi.common.core.web.page.TableDataInfo;

/**
 * 能源策略Controller
 *
 * @author ruoyi
 * @date 2024-08-08
 */
@RestController
@RequestMapping("/energyStrategy")
@Api(value = "OpEnergyStrategyController", description = "能源策略管理接口")
public class OpEnergyStrategyController extends BaseController
{
    @Autowired
    private IOpEnergyStrategyService admOpEnergyStrategyService;

    /**
     * 查询能源策略列表
     */
    @RequiresPermissions("power-mgr:strategy:list")
    @GetMapping("/list")
    public TableDataInfo list(OpEnergyStrategy admOpEnergyStrategy)
    {
        startPage();
        List<OpEnergyStrategy> list = admOpEnergyStrategyService.selectOpEnergyStrategyList(admOpEnergyStrategy);
        return getDataTable(list);
    }

    /**
     * 导出能源策略列表
     */
    @RequiresPermissions("power-mgr:strategy:export")
    @Log(title = "能源策略", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, OpEnergyStrategy admOpEnergyStrategy)
    {
        List<OpEnergyStrategy> list = admOpEnergyStrategyService.selectOpEnergyStrategyList(admOpEnergyStrategy);
        ExcelUtil<OpEnergyStrategy> util = new ExcelUtil<OpEnergyStrategy>(OpEnergyStrategy.class);
        util.exportExcel(response, list, "能源策略数据");
    }

    /**
     * 获取能源策略详细信息
     */
    @RequiresPermissions("power-mgr:strategy:query")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(admOpEnergyStrategyService.selectOpEnergyStrategyById(id));
    }

    /**
     * 新增能源策略
     */
    @RequiresPermissions("power-mgr:strategy:add")
    @Log(title = "能源策略", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody OpEnergyStrategy admOpEnergyStrategy)
    {
        return toAjax(admOpEnergyStrategyService.insertOpEnergyStrategy(admOpEnergyStrategy));
    }

    /**
     * 修改能源策略
     */
    @RequiresPermissions("power-mgr:strategy:edit")
    @Log(title = "能源策略", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody OpEnergyStrategy admOpEnergyStrategy)
    {
        return toAjax(admOpEnergyStrategyService.updateOpEnergyStrategy(admOpEnergyStrategy));
    }

    /**
     * 删除能源策略
     */
    @RequiresPermissions("power-mgr:strategy:remove")
    @Log(title = "能源策略", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(admOpEnergyStrategyService.deleteOpEnergyStrategyByIds(ids));
    }
}
